==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/it.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gestire i parametri ID gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "gestire Galleria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Ingrandimento Larghezza");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ingrandimento Altezza");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Larghezza");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Altezza");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Conserva Thumb proporzioni");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostra titoli");
define('MANAGE_GALLERY_DISABLE_SORT', "Disabilitare Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Elimina Immagine");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salva Specie di ordine");
define('MANAGE_GALLERY_PUBLISH_MSG', "Fare clic su &#39;Aggiorna&#39; di pubblicare <br /> le immagini caricate.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tutte le immagini sono state ridimensionate e le impostazioni sono state salvate.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "C&#39;è stato un errore ridimensionare le immagini o il salvataggio delle impostazioni.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "La tua immagine (s) è stato caricato.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Si è verificato un errore durante il caricamento di immagini (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Il file che si sta tentando di caricare non è un&#39;immagine.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Il file che si sta tentando di caricare è troppo grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Il titolo è stato salvato.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sei sicuro di voler eliminare l&#39;immagine");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L&#39;immagine è stata eliminata.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "C&#39;è stato un errore eliminare l&#39;immagine.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvare i parametri e il ridimensionamento delle immagini, si prega di attendere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Caricamento in corso ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordinamento non è stata salvata. Vuoi salvare l&#39;ordinamento?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordine di immagine tipo è stato salvato.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Si è verificato un errore durante il salvataggio dell&#39;immagine sorta.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/it.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Gestire i parametri ID gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "gestire Galleria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Ingrandimento Larghezza");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ingrandimento Altezza");
define('MANAGE_GALLERY_THUMB_WIDTH', "Miniatura Larghezza");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Miniatura Altezza");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Conserva Thumb proporzioni");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostra titoli");
define('MANAGE_GALLERY_DISABLE_SORT', "Disabilitare Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Elimina Immagine");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salva Specie di ordine");
define('MANAGE_GALLERY_PUBLISH_MSG', "Fare clic su &#39;Aggiorna&#39; di pubblicare <br /> le immagini caricate.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tutte le immagini sono state ridimensionate e le impostazioni sono state salvate.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "C&#39;è stato un errore ridimensionare le immagini o il salvataggio delle impostazioni.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "La tua immagine (s) è stato caricato.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Si è verificato un errore durante il caricamento di immagini (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Il file che si sta tentando di caricare non è un&#39;immagine.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Il file che si sta tentando di caricare è troppo grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Il titolo è stato salvato.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sei sicuro di voler eliminare l&#39;immagine");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "L&#39;immagine è stata eliminata.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "C&#39;è stato un errore eliminare l&#39;immagine.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvare i parametri e il ridimensionamento delle immagini, si prega di attendere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Caricamento in corso ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "L&#39;ordinamento non è stata salvata. Vuoi salvare l&#39;ordinamento?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "L&#39;ordine di immagine tipo è stato salvato.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Si è verificato un errore durante il salvataggio dell&#39;immagine sorta.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Il file che stai tentando di caricare è più grande delle impostazioni PHP &quot;upload_max_filesize&quot; o &quot;post_max_size&quot;. Contattare l&#39;amministratore di sistema per aumentare questi limiti.");
?>
